=== removed file 'hooks/ceph-client-relation-changed'
--- hooks/ceph-client-relation-changed	2013-06-14 09:49:39 +0000
+++ hooks/ceph-client-relation-changed	1970-01-01 00:00:00 +0000
@@ -1,39 +0,0 @@
-#!/usr/bin/python
-
-import os
-import sys
-
-from subprocess import CalledProcessError
-from common import get_relation_config, chown, log
-from ceph import (
-    get_ceph_client_path, write_ceph_client_keyring, write_ceph_client_config)
-
-
-relation_config = get_relation_config()
-# The key is only reported once the ceph ring has quorum (there are enough
-# nodes in the service). There's nothing to do until the key is provided.
-if "key" not in relation_config:
-    log("Ceph key not reported in relation config, nothing to do.")
-    sys.exit(0)
-
-ceph_client_dir = get_ceph_client_path()
-if not os.path.exists(ceph_client_dir):
-    os.mkdir(ceph_client_dir)
-    chown(ceph_client_dir)
-
-# Create ceph client keyring and config for landscape-client use.
-try:
-    keyring_file = write_ceph_client_keyring(
-        "landscape-client", relation_config["key"])
-except CalledProcessError as err:
-    log("Writing ceph keyring file failed with code %d" % err.returncode)
-    sys.exit(1)
-
-try:
-    write_ceph_client_config(
-        relation_config["auth"], keyring_file,
-        relation_config["private-address"])
-    log("Ceph configuration written to file.")
-except IOError as err:
-    log("Writing ceph configuratin file failed: %s" % err)
-    sys.exit(1)

=== added symlink 'hooks/ceph-client-relation-changed'
=== target is 'hooks.py'
=== modified file 'hooks/ceph.py'
--- hooks/ceph.py	2013-06-06 07:56:47 +0000
+++ hooks/ceph.py	2013-11-19 12:39:44 +0000
@@ -1,7 +1,7 @@
 import os
 from subprocess import check_output
 
-from common import get_client_config, chown
+from common import LandscapeBroker, chown
 
 
 CEPH_CLIENT_DIR = "ceph-client"
@@ -16,19 +16,19 @@
 """
 
 
-def get_ceph_client_path():
+def get_ceph_client_path(landscape_broker):
     """Return the path for ceph client conf and keyring."""
-    config = get_client_config()
-    return os.path.join(config.data_path, CEPH_CLIENT_DIR)
-
-
-def write_ceph_client_keyring(name, key):
+    return os.path.join(landscape_broker.config.data_path, CEPH_CLIENT_DIR)
+
+
+def write_ceph_client_keyring(landscape_broker, name, key):
     """Creates a ceph client keyring with the specified name and key.
 
     @param name: name of the key
     @param key: the key to include in the keyring
     """
-    keyring_file = os.path.join(get_ceph_client_path(), CEPH_CLIENT_KEYRING)
+    keyring_file = os.path.join(
+        get_ceph_client_path(landscape_broker), CEPH_CLIENT_KEYRING)
     check_output(
         ["ceph-authtool", keyring_file, "--create-keyring",
          "--name=client.%s" % name, "--add-key=%s" % key])
@@ -36,14 +36,15 @@
     return keyring_file
 
 
-def write_ceph_client_config(auth, keyring, mon_address):
+def write_ceph_client_config(landscape_broker, auth, keyring, mon_address):
     """Write ceph client configuration file.
 
     @param auth: authentication type
     @param keyring: absolute path of the keyring file
     @param mon_address: address of the ceph monitor
     """
-    ceph_client_conf = os.path.join(get_ceph_client_path(), CEPH_CLIENT_CONF)
+    ceph_client_conf = os.path.join(
+        get_ceph_client_path(landscape_broker), CEPH_CLIENT_CONF)
     with open(ceph_client_conf, "w") as file:
         file.write(
             CONF_TEMPLATE % {

=== modified file 'hooks/common.py'
--- hooks/common.py	2013-11-08 16:01:57 +0000
+++ hooks/common.py	2013-11-19 12:39:44 +0000
@@ -11,11 +11,6 @@
 from landscape.sysvconfig import SysVConfig
 
 
-def log(message):
-    """Log a message via Juju."""
-    return check_output(["juju-log", message])
-
-
 class JujuBroker(object):
     """Class responsible for communicating with Juju.
 
@@ -35,6 +30,11 @@
         """Get service configuration from Juju."""
         return self._run_juju_tool("config-get")
 
+    def log(self, message):
+        """Log a message via Juju."""
+        # --format is deprecated for juju-log
+        return check_output(["juju-log", message])
+
     def _run_juju_tool(self, command):
         """Run specified Juju tool and parse json output."""
         output = check_output([command, "--format", "json"])
@@ -90,7 +90,6 @@
         """
         stop_client_and_disable_init_script()
 
-
     def try_to_register(self):
         """Try to register the client if needed.
 

=== modified file 'hooks/hooks.py'
--- hooks/hooks.py	2013-11-11 07:28:14 +0000
+++ hooks/hooks.py	2013-11-19 12:39:44 +0000
@@ -3,8 +3,11 @@
 import sys
 import os
 import base64
+from subprocess import CalledProcessError
 
-from common import write_json_file, JujuBroker, LandscapeBroker
+from common import write_json_file, JujuBroker, LandscapeBroker, chown
+from ceph import (
+    get_ceph_client_path, write_ceph_client_keyring, write_ceph_client_config)
 
 
 def _write_certificate(certificate, filename):
@@ -103,6 +106,41 @@
     return exit_code
 
 
+def ceph_relation_changed(juju_broker, landscape_broker):
+    relation_config = juju_broker.get_relation_config()
+    # The key is only reported once the ceph ring has quorum (there are enough
+    # nodes in the service). There's nothing to do until the key is provided.
+    if "key" not in relation_config:
+        juju_broker.log(
+            "Ceph key not reported in relation config, nothing to do.")
+        return 0
+
+    ceph_client_dir = get_ceph_client_path(landscape_broker)
+    if not os.path.exists(ceph_client_dir):
+        os.mkdir(ceph_client_dir)
+        chown(ceph_client_dir)
+
+    # Create ceph client keyring and config for landscape-client use.
+    try:
+        keyring_file = write_ceph_client_keyring(
+            landscape_broker, "landscape-client", relation_config["key"])
+    except CalledProcessError as err:
+        juju_broker.log(
+            "Writing ceph keyring file failed with code %d" % err.returncode)
+        return 1
+
+    try:
+        write_ceph_client_config(
+            landscape_broker, relation_config["auth"], keyring_file,
+            relation_config["private-address"])
+    except IOError as err:
+        juju_broker.log("Writing ceph configuration file failed: %s" % err)
+        return 1
+    else:
+        juju_broker.log("Ceph configuration written to file.")
+        return 0
+
+
 HOOKS = {
     "config-changed": config_changed,
     "upgrade-charm": upgrade_charm,
@@ -114,6 +152,7 @@
     "container-relation-departed": lambda juju_broker, landscape_broker:
         landscape_broker.clear_registration(),
     "ceph-client-relation-joined": container_relation_joined,
+    "ceph-client-relation-changed": ceph_relation_changed,
     "ceph-client-relation-departed": lambda juju_broker, landscape_broker:
         landscape_broker.clear_registration()}
 

=== modified file 'hooks/test_hooks.py'
--- hooks/test_hooks.py	2013-11-07 17:39:49 +0000
+++ hooks/test_hooks.py	2013-11-19 12:39:44 +0000
@@ -7,11 +7,11 @@
 
 from landscape.deployment import Configuration
 from landscape.lib.fs import read_file
-from hooks import migrate_old_juju_info, HOOKS
-from common import JujuBroker, LandscapeBroker
-
-
-class FakeJujuBroker(JujuBroker):
+import hooks
+import common
+
+
+class FakeJujuBroker(common.JujuBroker):
     """A JujuBroker that can be used in unit tests.
 
     Instead of executing commands, it returns the output from
@@ -23,14 +23,18 @@
         self.environment = {
             "JUJU_ENV_UUID": str(uuid4()),
             "JUJU_API_ADRESSES": "juju.example.com:12345"}
+        self.logs = []
+
+    def log(self, message):
+        self.logs.append(message)
 
     def _run_juju_tool(self, command):
         """Override _run_juju_tool not not execute any commands."""
         return self.commands[command]
 
 
-class FakeLandscapeBroker(LandscapeBroker):
-    """A LandscapeBroker taht can be use in unittests."""
+class FakeLandscapeBroker(common.LandscapeBroker):
+    """A LandscapeBroker that can be use in unittests."""
 
     def try_to_register(self):
         """Don't check system files or try to actually register the client."""
@@ -64,7 +68,7 @@
                      "juju-api-addresses": "10.0.3.1:17070",
                      "juju-private-address": "10.0.3.205"}
         self.setup_old_juju_info(juju_info)
-        migrate_old_juju_info(self.config)
+        hooks.migrate_old_juju_info(self.config)
         juju_info_path = os.path.join(self.config.data_path, "juju-info.json")
         self.assertTrue(os.path.exists(juju_info_path))
         with open(juju_info_path) as juju_info_fh:
@@ -85,7 +89,7 @@
                      "juju-api-addresses": "10.0.3.1:17070",
                      "juju-private-address": "10.0.3.205"}
         self.setup_old_juju_info(juju_info)
-        migrate_old_juju_info(self.config)
+        hooks.migrate_old_juju_info(self.config)
         self.assertEqual([], os.listdir(self.config.meta_data_path))
 
     def test_incomplete_juju_info_is_error(self):
@@ -97,7 +101,7 @@
                      "juju-api-addresses": "10.0.3.1:17070",
                      "juju-private-address": "10.0.3.205"}
         self.setup_old_juju_info(juju_info)
-        self.assertNotEqual(0, migrate_old_juju_info(self.config))
+        self.assertNotEqual(0, hooks.migrate_old_juju_info(self.config))
         self.assertGreater(len(os.listdir(self.config.meta_data_path)), 0)
 
     def test_idempotent(self):
@@ -110,8 +114,8 @@
                      "juju-api-addresses": "10.0.3.1:17070",
                      "juju-private-address": "10.0.3.205"}
         self.setup_old_juju_info(juju_info)
-        migrate_old_juju_info(self.config)
-        self.assertEqual(0, migrate_old_juju_info(self.config))
+        hooks.migrate_old_juju_info(self.config)
+        self.assertEqual(0, hooks.migrate_old_juju_info(self.config))
 
 
 class ContainerRelationJoinedTest(TestCase):
@@ -128,7 +132,7 @@
         self.landscape_broker.config.write()
         self.juju_broker = FakeJujuBroker()
         self.juju_broker.environment["JUJU_REMOTE_UNIT"] = "remote/0"
-        self.hook = HOOKS["container-relation-joined"]
+        self.hook = hooks.HOOKS["container-relation-joined"]
 
     def test_writes_juju_json(self):
         """
@@ -171,3 +175,118 @@
         self.hook(self.juju_broker, self.landscape_broker)
 
         self.assertEqual([True], registration_attempts)
+
+
+class CephClientRelationJoinedTest(TestCase):
+    """Test for the ceph-client-relation-changed hook."""
+
+    def setUp(self):
+        data_path = mkdtemp(prefix=self.__class__.__name__)
+        self.addCleanup(rmtree, data_path)
+        self.landscape_broker = FakeLandscapeBroker()
+        self.landscape_broker.config.data_path = data_path
+        self.landscape_broker.config.config = os.path.join(
+            data_path, "landscape.conf")
+        # self.landscape_broker.config.account_name = "account1"
+        self.landscape_broker.config.write()
+        self.juju_broker = FakeJujuBroker()
+        self.chowned_files = []
+
+        def stub_chown(filepath):
+            self.chowned_files.append(filepath)
+        hooks.chown = stub_chown
+        # self.juju_broker.environment["JUJU_REMOTE_UNIT"] = "remote/0"
+        self.hook = hooks.HOOKS["ceph-client-relation-changed"]
+
+    def test_nothing_to_do_with_no_key(self):
+        """
+        If there's no key in the relation information provided by ceph,
+        log and do nothing.
+        """
+        self.assertEqual(0, self.hook(self.juju_broker, self.landscape_broker))
+
+        [log] = self.juju_broker.logs
+        self.assertEqual(
+            "Ceph key not reported in relation config, nothing to do.", log)
+
+    def test_ceph_client_path_made(self):
+        """
+        If the ceph client path doesn't exist already it's created and chowned.
+        """
+        self.juju_broker.commands["relation-get"] = {
+            "key": "foo", "auth": "bar", "private-address": "home"}
+
+        def stub_ceph_write(*args):
+            pass
+        hooks.write_ceph_client_keyring = stub_ceph_write
+        hooks.write_ceph_client_config = stub_ceph_write
+
+        self.assertEqual(0, self.hook(self.juju_broker, self.landscape_broker))
+
+        ceph_client_dir = os.path.join(
+            self.landscape_broker.config.data_path, "ceph-client")
+        self.assertTrue(os.path.exists(ceph_client_dir))
+        self.assertEqual([ceph_client_dir], self.chowned_files)
+
+    def test_write_ceph_client_keyring_called(self):
+        """
+        write_ceph_client_keyring is called with the key from the Juju
+        relation config.
+        """
+        self.juju_broker.commands["relation-get"] = {
+            "key": "foo", "auth": "bar", "private-address": "home"}
+
+        called_args = []
+
+        def stub_write_ceph_client_keyring(*args):
+            called_args.append(args)
+
+        hooks.write_ceph_client_keyring = stub_write_ceph_client_keyring
+
+        def stub_ceph_write(*args):
+            pass
+        hooks.write_ceph_client_config = stub_ceph_write
+
+        self.assertEqual(0, self.hook(self.juju_broker, self.landscape_broker))
+        [args] = called_args
+        self.assertEqual(
+            (self.landscape_broker, "landscape-client", "foo"), args)
+
+    def test_write_ceph_client_config_called(self):
+        """
+        write_ceph_client_config is called with the auth and
+        private-address from the Juju relation config.
+        """
+        self.juju_broker.commands["relation-get"] = {
+            "key": "foo", "auth": "bar", "private-address": "home"}
+
+        called_args = []
+        keyring_file = object()
+
+        def stub_ceph_write(*args):
+            return keyring_file
+
+        hooks.write_ceph_client_keyring = stub_ceph_write
+
+        def stub_write_ceph_client_config(*args):
+            called_args.append(args)
+        hooks.write_ceph_client_config = stub_write_ceph_client_config
+
+        self.assertEqual(0, self.hook(self.juju_broker, self.landscape_broker))
+        [args] = called_args
+        self.assertEqual(
+            (self.landscape_broker, "bar", keyring_file, "home"), args)
+
+    def test_confirmation_logged(self):
+        self.juju_broker.commands["relation-get"] = {
+            "key": "foo", "auth": "bar", "private-address": "home"}
+
+        def stub_ceph_write(*args):
+            pass
+        hooks.write_ceph_client_keyring = stub_ceph_write
+        hooks.write_ceph_client_config = stub_ceph_write
+
+        self.assertEqual(0, self.hook(self.juju_broker, self.landscape_broker))
+
+        [log] = self.juju_broker.logs
+        self.assertEqual("Ceph configuration written to file.", log)

=== modified file 'revision'
--- revision	2013-11-11 07:28:14 +0000
+++ revision	2013-11-19 12:39:44 +0000
@@ -1,1 +1,1 @@
-14
+15

